@@ -1,5 +1,5 @@
 from pydantic import BaseModel, Field, validator
-from typing import List, Optional, Union
+from typing import List, Optional, Union, Dict, Tuple
 
 
 class TableProperties(BaseModel):
@@ -11,15 +11,15 @@ class Column(BaseModel):
 
     name: str
     type: str
-    size: Optional[Union[str, int, tuple]]
+    size: Optional[Union[str, int, Tuple]]
     primary_key: bool = False
     unique: bool = False
     default: Optional[str]
     nullable: bool = True
     identifier: Optional[bool]
     generated_as: Optional[str]
-    other_properties: Optional[dict]
-    references: Optional[dict]
+    other_properties: Optional[Dict]
+    references: Optional[Dict]
 
     @validator("size")
     def size_must_contain_space(cls, v):
@@ -32,9 +32,9 @@ class TableMeta(BaseModel):
     name: str = Field(alias="table_name")
     table_schema: Optional[str] = Field(alias="schema")
     columns: List[Column]
-    indexes: Optional[List[dict]] = Field(alias="index")
-    alter: Optional[dict] = {}
-    checks: Optional[List[dict]]
+    indexes: Optional[List[Dict]] = Field(alias="index")
+    alter: Optional[Dict] = {}
+    checks: Optional[List[Dict]]
     properties: Optional[TableProperties]
     primary_key: List
     parents: Optional[List[str]]
@@ -49,4 +49,6 @@ class Type(BaseModel):
     name: str = Field(alias="type_name")
     base_type: str
     parents: Optional[List[str]]
-    properties: Optional[dict]
+    properties: Optional[Dict]
+    attrs: Optional[List[Dict]]
+
